@@ -3,15 +3,16 @@ import pyodbc
 from .models.model import ClientModel
 
 class DatabaseClient(ClientModel):
-    def __init__(self, server, database, username, password, driverLocation, *args, **kwargs):
+    ''' database client is a client model that is used to get data from a database '''
+    def __init__(self, server, database, username, password, driver_location, *args, **kwargs):
         self.server=server
         self.database=database
         self.username=username
         self.password=password
-        self.driverLocation=driverLocation
-        if self.databaseType().lower() == "mssql":
+        self.driver_location=driver_location
+        if self.database_type().lower() == "mssql":
             self.cnxn = pyodbc.connect(
-                "DRIVER="+str(driverLocation)+";"+
+                "DRIVER="+str(driver_location)+";"+
                 "SERVER="+str(server)+";"+
                 "DATABASE="+str(database)+";"+
                 "UID="+str(username)+";"+
@@ -19,37 +20,38 @@ class DatabaseClient(ClientModel):
             , timeout=5)
             self.cursor = self.cnxn.cursor()
         else:
-            self.cursor=self.getCursorFromDatabase(
+            self.cursor=self.get_cursor_from_database(
                 self.server,
                 self.database,
                 self.username,
                 self.password,
-                self.driverLocation
+                self.driver_location
             )
         super().__init__(*args, **kwargs)
 
-    def getCursor(self):
-        return self.cursor
-
     @abstractmethod
-    def databaseType(self):
+    def database_type(self):
+        ''' abstract method to get the database type '''
         return "MSSQL"
 
-    def getCursorFromDatabase(self,
+    def get_cursor_from_database(self,
         server:str,
         database:str,
         username:str,
         password:str,
-        driverLocation:str
+        driver_location:str
     ):
-        raise NotImplementedError("getCursorFromDatabase is not implemented")
+        ''' get the cursor from the database '''
+        raise NotImplementedError("get_cursor_from_database is not implemented")
 
     def fetchall(self, query:str):
+        ''' fetch all the rows from the database '''
         self.cursor.execute(query)
-        rowAll = self.cursor.fetchall()
-        return rowAll
+        row_all = self.cursor.fetchall()
+        return row_all
 
     def fetchone(self, query:str):
+        ''' fetch one row from the database '''
         self.cursor.execute(query)
         row = self.cursor.fetchone()
         return row
\ No newline at end of file
