@@ -23,12 +23,15 @@ class RedisClient(ClientModel):
         key:str,
         value:str
     ):
+        ''' Set a key/value pair in a hash '''
         self.redis.hset(array_name, key, value)
 
     def hgetall(self, array_name:str) -> list:
+        ''' Get all the values in a hash '''
         return self.redis.hgetall(array_name)
 
     def set_dict_using_global_selector(self, global_selector:str, array_name:str, set_item_key:str):
+        ''' Set a key/value pair into the main dictionary '''
         array = self.hgetall(array_name)
         for key in array:
             if key.startswith(global_selector):
